package com.miaxis.teachingDsp.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.enums.FileUploadTypeEnum;
import com.miaxis.common.exception.CustomException;
import com.miaxis.file.domain.FileInfo;
import com.miaxis.file.service.IFileInfoService;
import com.miaxis.teachingDsp.domain.TeachingDspInfo;
import com.miaxis.teachingDsp.mapper.TeachingDspInfoMapper;
import com.miaxis.teachingDsp.service.ITeachingDspInfoService;
import com.tencentcloudapi.vod.v20180717.VodClient;
import com.tencentcloudapi.vod.v20180717.models.DescribeMediaInfosResponse;
import com.tencentcloudapi.vod.v20180717.models.ModifyMediaInfoRequest;
import com.tencentcloudapi.vod.v20180717.models.ModifyMediaInfoResponse;
import lombok.AllArgsConstructor;
import org.apache.commons.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 学车短视频Service业务层处理
 *
 * @author miaxis
 * @date 2021-12-09
 */
@Service
@AllArgsConstructor
public class TeachingDspInfoServiceImpl extends ServiceImpl<TeachingDspInfoMapper, TeachingDspInfo> implements ITeachingDspInfoService {

    @Autowired
    private TeachingDspInfoMapper teachingDspInfoMapper;

    private final IFileInfoService fileInfoService;

    private final VodClient vodClient;

    /**
     * 查询学车短视频列表
     *
     * @param teachingDspInfo 学车短视频
     * @return 学车短视频
     */
    @Override
    public List<TeachingDspInfo> selectTeachingDspInfoList(TeachingDspInfo teachingDspInfo){
        return teachingDspInfoMapper.selectTeachingDspInfoList(teachingDspInfo);
    }


    /**
     * 上架教学视频
     * @param ids
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Response removePutShelfByIds(Long[] ids) {
        for (Long id : ids) {
            this.update(new UpdateWrapper<TeachingDspInfo>().set("shelf_status",0).eq("id",id));
        }
        return Response.success();
    }

    /**
     * 下架教学视频
     * @param ids
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Response removeOffShelfByIds(Long[] ids) {
        for (Long id : ids) {
            this.update(new UpdateWrapper<TeachingDspInfo>().set("shelf_status",1).eq("id",id));
        }
        return Response.success();
    }

    @Override
    public Response coverUp(String fileId, MultipartFile coverFile) {
        try{
            byte[] refereeFileBase64Bytes = Base64.encodeBase64(coverFile.getBytes());
            String UpFile = new String(refereeFileBase64Bytes, "UTF-8");
            System.out.println(UpFile);

            ModifyMediaInfoRequest req = new ModifyMediaInfoRequest();
            req.setFileId(fileId);
            req.setCoverData(UpFile);

            ModifyMediaInfoResponse resp = vodClient.ModifyMediaInfo(req);
            JSONObject jsonObject = JSONObject.parseObject(DescribeMediaInfosResponse.toJsonString(resp));
            String coverUrl = (String) jsonObject.get("CoverUrl");//封面访问路径

            //保存封面文件信息
            FileInfo cover = new FileInfo();
            cover.setFileType(FileUploadTypeEnum.STUDY_DSP.getFileType());
            cover.setFileUrl(coverUrl);
            cover.setRemark("视频封面");
            fileInfoService.save(cover);

            return Response.success(cover);
        }catch (Exception e){
            throw new CustomException("系统异常");
        }
    }


}
